##  Prerequisites
  * In SAP LeanIX:
    * Meta model v4, including the platform fact sheet type. Learn more in [Introduce New Fact Sheet Type - Platform](https://help.sap.com/docs/leanix/ea/configure-workspace-meta-model-v4?locale=en-US&state=PRODUCTION&version=CLOUD#loio27595ce97a4410149c60a90e0f529a04__introduce_new_fact_sheet_type_-_platform).
    * Administrator access to your workspace.
  * Admin access to SAP Build Process Automation.
  * Admin access to a service instance of “SAP Cloud Management Service” of SAP BTP with the service plan “central-viewer”.


The integration uses a service key to access the SAP Build Process Automation API. This method allows you to manage access without relying on individual user accounts.
